@@ -13,7 +13,7 @@ module RbConfig
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "9"
   CONFIG["TEENY"] = "1"
-  CONFIG["PATCHLEVEL"] = "484"
+  CONFIG["PATCHLEVEL"] = "545"
   CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
@@ -32,7 +32,7 @@ module RbConfig
   CONFIG["rubyhdrdir"] = "$(includedir)/$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--program-suffix=19' '--with-soname=ruby19' '--enable-pthread' '--enable-ipv6' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
+  CONFIG["configure_args"] = " '--program-suffix=19' '--with-soname=ruby19' '--enable-pthread' '--enable-ipv6' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-tcllib=tcl85' '--with-tklib=tk85' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
   CONFIG["vendordir"] = "$(rubylibprefix)/vendor_ruby"
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["ruby_version"] = "1.9.1"
@@ -99,6 +99,7 @@ module RbConfig
   CONFIG["ARCH_FLAG"] = ""
   CONFIG["DLDFLAGS"] = ""
   CONFIG["ALLOCA"] = ""
+  CONFIG["codesign"] = ""
   CONFIG["POSTLINK"] = ":"
   CONFIG["WERRORFLAG"] = "-Werror"
   CONFIG["CHDIR"] = "cd -P"
@@ -142,21 +143,21 @@ module RbConfig
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -Wl,-E"
   CONFIG["CFLAGS"] = "-O2 -pipe -fPIC"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd5.5"
+  CONFIG["target_os"] = "openbsd5.6"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "powerpc"
-  CONFIG["target"] = "powerpc-unknown-openbsd5.5"
-  CONFIG["host_os"] = "openbsd5.5"
+  CONFIG["target"] = "powerpc-unknown-openbsd5.6"
+  CONFIG["host_os"] = "openbsd5.6"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "powerpc"
-  CONFIG["host"] = "powerpc-unknown-openbsd5.5"
+  CONFIG["host"] = "powerpc-unknown-openbsd5.6"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd5.5"
+  CONFIG["build_os"] = "openbsd5.6"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "powerpc"
-  CONFIG["build"] = "powerpc-unknown-openbsd5.5"
-  CONFIG["RUBY_RELEASE_DATE"] = "2013-11-22"
+  CONFIG["build"] = "powerpc-unknown-openbsd5.6"
+  CONFIG["RUBY_RELEASE_DATE"] = "2014-02-24"
   CONFIG["RUBY_PROGRAM_VERSION"] = "1.9.3"
   CONFIG["BASERUBY"] = "echo executable host ruby is required.  use --with-baseruby option.; false"
   CONFIG["target_alias"] = ""
